<?php
/**
 * @file
 * Wunderground admin settings.
 */

/**
 * Admin settings form.
 */
function wunderground_weather_admin_form() {

  // Get enabled languages.
  $languages = array();
  $list = language_list('enabled');
  foreach ($list[1] as $key => $value) {
    $languages[$key] = $value->name;
  }

  // URL to get the api key.
  $wg_link = l(t('http://www.wunderground.com/weather/api'), 'http://www.wunderground.com/weather/api');

  $form = array();

  $form['wunderground_weather_api_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Wunderground API key'),
    '#description' => filter_xss(t('Get your API key at !url', array('!url' => $wg_link))),
    '#default_value' => variable_get('wunderground_weather_api_key', ''),
    '#required' => TRUE,
  );

  $form['wunderground_weather_language'] = array(
    '#type' => 'select',
    '#title' => t('Language'),
    '#options' => $languages,
    '#default_value' => variable_get('wunderground_weather_language', ''),
  );

  $form['location'] = array(
    '#type' => 'fieldset',
    '#title' => t('Location'),
  );

  $form['location']['wunderground_weather_screen'] = array(
    '#title' => t('Display name'),
    '#type' => 'textfield',
    '#description' => t('Location to display on screen.'),
    '#default_value' => variable_get('wunderground_weather_screen', ''),
    '#required' => TRUE,
  );
  // Autocomplete to get location.
  $form['location']['wunderground_weather_location'] = array(
    '#title' => t('Location path'),
    '#type' => 'textfield',
    '#description' => t('Search for your city to determine the Wunderground location path.'),
    '#maxlength' => 60,
    '#autocomplete_path' => 'wunderground-locations',
    '#default_value' => variable_get('wunderground_weather_location', ''),
  );

  $form['wunderground_weather_cache'] = array(
    '#title' => t('Cache weather data'),
    '#description' => t('Caching will reduce the number of call to Wunderground and is a lot faster. If you choose not to cache, you will have the most up to date data in your blocks.'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('wunderground_weather_cache', 1),
  );

  $form['settigs_current'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings current weather conditions block'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $settigs_current_defaults = array(
    'weather' => 'weather',
    'conditions' => 'conditions',
    'temperature' => 'temperature',
    'feels_like' => 'feels_like',
    'wind' => 'wind',
  );

  $form['settigs_current']['wunderground_weather_current_fields'] = array(
    '#title' => t('Fields'),
    '#type' => 'checkboxes',
    '#options' => array(
      'weather' => t('Weather description'),
      'temperature' => t('Temperature'),
      'feels_like' => t('Feels like'),
      'wind' => t('Wind speed'),
    ),
    '#default_value' => variable_get('wunderground_weather_current_fields', $settigs_current_defaults),
  );

  $form['settigs_forecast'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings weather forecast block'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $settigs_forecast_defaults = array(
    'image' => 'image',
    'conditions' => 'conditions',
    'temperature' => 'temperature',
    'rain' => 'rain',
    'wind' => 'wind',
  );

  $form['settigs_forecast']['wunderground_weather_forecast_fields'] = array(
    '#title' => t('Fields'),
    '#type' => 'checkboxes',
    '#options' => array(
      'image' => t('Weather icons'),
      'conditions' => t('Weather description'),
      'temperature' => t('Temperature'),
      'rain' => t('Chance of rain'),
      'wind' => t('Wind speed'),
    ),
    '#default_value' => variable_get('wunderground_weather_forecast_fields', $settigs_forecast_defaults),
  );

  return system_settings_form($form);
}


/**
 * Autocomplete function to get locations from the Wunderground database.
 *
 * @param string $text
 *   Input from the autocomplete widget.
 */
function wunderground_weather_location_autocomplete($text = '') {
  $query = urlencode($text);
  $request_url = 'http://autocomplete.wunderground.com/aq?query=' . $query;

  // Get data from wunderground.
  $response = drupal_http_request($request_url);

  if ($response->code == 200) {
    $data = drupal_json_decode($response->data);
  }

  // Extract key and value from the returned array.
  $results = array();
  foreach ($data['RESULTS'] as $result) {
    $results[$result['name'] . ' [' . $result['l'] . ']'] = $result['name'];
  }
  // Return as json.
  drupal_json_output($results);
}
